package cz.moneta.test.dsl.ufo.banka.pages.common.pages;

import cz.moneta.test.dsl.ufo.banka.pages.cards.credit.HPO019_S001_CreditCardDetailPage;
import cz.moneta.test.dsl.ufo.banka.pages.cards.credit.HPO039_S001_MbcDetailPage;
import cz.moneta.test.dsl.ufo.banka.pages.cards.credit.OPN008_S001_SignContractPage;
import cz.moneta.test.dsl.ufo.banka.pages.cards.credit.POZ001_S007_CreditCardServiceOperationsPage;
import cz.moneta.test.dsl.ufo.banka.pages.cards.debit.HPO009_S001_DebitCardDetailPage;
import cz.moneta.test.dsl.ufo.banka.pages.cards.debit.OBR003_S001_ClientContractSignPage;
import cz.moneta.test.dsl.ufo.banka.pages.fon.*;
import cz.moneta.test.dsl.ufo.banka.pages.ib.ADC001_S001_IbPasswordKeyPage;
import cz.moneta.test.dsl.ufo.banka.pages.ib.ADC047_S001_IbSettingsPage;
import cz.moneta.test.dsl.ufo.banka.pages.insurance.IDD001_S001_IndividualInsuranceFormPage;
import cz.moneta.test.dsl.ufo.banka.pages.loans.CAS001_S001_ScoringPage;
import cz.moneta.test.dsl.ufo.banka.pages.loans.creditCard.NKK006_S001_CreditCardScoringResultPage;
import cz.moneta.test.dsl.ufo.banka.pages.loans.creditCard.ONC001_S001_NewCreditCardPage;
import cz.moneta.test.dsl.ufo.banka.pages.loans.expres.NEP001_S001_NewExpressPage;
import cz.moneta.test.dsl.ufo.banka.pages.loans.expres.NEP009_S001_Existing_ApplicationsPage;
import cz.moneta.test.dsl.ufo.banka.pages.main.*;
import cz.moneta.test.dsl.ufo.banka.pages.main.client.settings.*;
import cz.moneta.test.dsl.ufo.banka.pages.main.components.ADC001_OBR001_002_IbTypeSelectionPage;
import cz.moneta.test.dsl.ufo.banka.pages.main.components.BUF051_S001_CreateCurrentAccountPage;
import cz.moneta.test.dsl.ufo.banka.pages.main.signature.patterns.NPV010_S001_PrintSignPadPage;
import cz.moneta.test.dsl.ufo.banka.pages.main.signature.patterns.NPV019_OBR001_ConfirmationPage;
import cz.moneta.test.dsl.ufo.banka.pages.main.signature.patterns.PVX043_S002_SignaturePatternsPage;
import cz.moneta.test.dsl.ufo.banka.pages.po.ZAS001_S001_StatutoryAuthorityPage;
import cz.moneta.test.dsl.ufo.banka.pages.products.current.account.BPP001_S001_DocumentationSendPage;
import cz.moneta.test.dsl.ufo.banka.pages.products.current.account.ZPL_OBR001_SmoothPaymentInfo;
import cz.moneta.test.dsl.ufo.banka.pages.products.debit.card.NPK001_S001_DebitCardRequestPage;
import cz.moneta.test.dsl.ufo.banka.pages.products.debit.card.NPK012_S001_DebitCardHolderSelectPage;
import cz.moneta.test.dsl.ufo.banka.pages.products.one.click.BAL021_S002_RecapitulationPage;
import cz.moneta.test.dsl.ufo.banka.pages.products.one.click.BAL024_S001_OneClickPage;
import cz.moneta.test.dsl.ufo.banka.pages.products.saving.accounts.SPU001_S001_SavingAccountPage;
import cz.moneta.test.dsl.ufo.banka.pages.products.sme.*;
import cz.moneta.test.dsl.ufo.banka.pages.term.deposit.RTV001_S001_TermDepositPage;
import cz.moneta.test.harness.support.web.WebFlow;

public interface OBR001_S001_PrintInstructionPageTransitions extends WebFlow<OBR001_S001_PrintInstructionPageTransitions> {

    KUL001_S001_SelectProductsPage onSelectProductsPage();

    KUL066_S001_ProcessedRequestsPage onProcessedRequestsPage();

    BPP001_S001_DocumentationSendPage onDocumentationSendPage();

    BAL024_S001_OneClickPage onOneClickPage();

    KUL051_S001_PreliminaryEvaluationPage onPreliminaryEvaluationPage();

    OBR001_S001_PrintInstructionPage onPrintInstructionPage();

    BUF051_S001_CreateCurrentAccountPage onCreateCurrentAccountPage();

    ADR004_S001_EnterContactAddressPage onEnterContactAddressPage();

    NPK001_S001_DebitCardRequestPage onDebitCardRequestPage();

    GDP001_S003_ClientConsentsPoPage onClientConsentsPoPage();

    PVX002_S002_AccountDispositionOwnerPage onAccountDispositionOwnerPage();

    ODS003_S001_AddCodeOfRecommendedPersonPage onAddCodeOfRecommendedPersonPage();

    EVY001_S003_ProductSummaryChangeAdcPage onProductSummaryChangeAdcPage();

    TIS051_S001_DispositionGeneratePage onDispositionGeneratePage();

    BAL021_S002_SummaryOfProductFoundationPage onSummaryOfProductFoundationPage();

    BAL021_S002_RecapitulationPage onRecapitulationPage();

    SPU031_S001_SavingsAccountConfirmationPage onSavingsAccountConfirmationPage();

    OBR003_S001_ClientContractSignPage onClientContractSignPage();

    HPO009_S001_DebitCardDetailPage onDebitCardDetailPage();

    PSP004_S001_PrintPage onPrintPage();

    HPO039_S001_MbcDetailPage onMbcDetailPage();

    ADC001_S001_IbPasswordKeyPage onIbPasswordKeyPage();

    HKO101_S001_MainClientPage onMainClientPage();

    BAL001_S008_SummaryStartDocumentsPage onSummaryStartDocumentsPage();

    OBR001_S001_PrintInstructionPageTransitions clickNo();

    RTV001_S001_TermDepositPage onTermDepositPage();

    ZAS001_S001_StatutoryAuthorityPage onStatutoryAuthorityPage();

    KUL004_S008_ClientRequestDetailPage onClientRequestDetailPage();

    SPU001_S001_SavingAccountPage onSavingsAccountPage();

    CAS001_S001_ScoringPage onScoringPage();

    TIS046_S001_DocumentsProvidedToClientPage onDocumentsProvidedToClientPage();

    POZ001_S007_CreditCardServiceOperationsPage onCreditCardServiceOperationsPage();

    TIS004_S002_SignerSelectionPage onSignerSelectionPage();

    ONC001_S001_NewCreditCardPage onNewCreditCardPage();

    HPO019_S001_CreditCardDetailPage onCreditCardDetailPage();

    CIF111_S016_CreateNewCifPage onCreateNewCif();

    TIS050_S001_SignerSelectionPage onSignerPage();

    TRP001_S002_ListOfStandingOrdersPage onListOfStandingOrdersPage();

    INK001_S002_ListOfAuthorizationForDirectDebitsPage onListOfDirectDebitsPage();

    IDD001_S001_IndividualInsuranceFormPage onInsurancePage();

    KUL024_S001_ListOfPersons onListOfPersons();

    DMS070_S001_ScanDocumentsPage onScanDocumentsPage();

    DMS001_S001_ScanDocumentsPage onScanDocumentsPageDMS001();

    PKU001_S002_CreatePaymentOrderPage onCreatePaymentOrderPage();

    ADC019_OBR001_AdcCreationPage onAdcCreationPage();

    POD003_S004_ClientCharged onClientChargedPage();

    SIP001_S002_ListOfSIPOPayments onListOfSIPOPaymentsPage();

    PVX043_S002_SignaturePatternsPage onSignaturePatternsPage();

    BAL035_S002_SummaryOfProductFoundationRetailPage onSummaryOfProductFoundationRetailPage();

    ADC012_S001_SettingADC onSettingADCPage();

    ADC001_OBR001_002_IbTypeSelectionPage onIbTypeSelectionPage();

    ADC047_S001_IbSettingsPage onIbSettingsPage();

    OPN008_S001_SignContractPage onSignContractor();

    NEP009_S001_Existing_ApplicationsPage onExistingApplicationsPage();

    NEP001_S001_NewExpressPage onExpressPage();

    NPV010_S001_PrintSignPadPage onPrintSignPadPage();

    ZPL_OBR001_SmoothPaymentInfo onSmoothPaymentInfo();

    NPK012_S001_DebitCardHolderSelectPage onDebitCardHolderSelectPage();

    NKK006_S001_CreditCardScoringResultPage onCreditCardScoringResultPage();

    TIS050_S002_SignerSelectionPage onSignerSelectionsPage();

    DMS001_S001_ScanDocumentsPage onDocumentScanPage();

    CIF113_S001_ChangeDataFO onChangeDataFO();

    NPV019_OBR001_ConfirmationPage onConfirmationPage();

    OBR003_S001_ClientContractSignPage onClientContractPage();
}